# Security Policy

## Supported Versions

Use this section to tell people about which versions of your project are
currently being supported with security updates.

| Version | Supported          |
| ------- | ------------------ |
| 9.x     | :white_check_mark: |
| < 9.0   | :x:                |

## Reporting a Vulnerability

We take the security of `seekify` seriously.

If you discover a security vulnerability, we appreciate your help in disclosing it to us in a responsible manner.

**Please do not open a public issue.**

Instead, please report the vulnerability by emailing **hello@seekify.dev**. We will attempt to verify and reproduce the issue and will get back to you as soon as possible.
